-- local m, s, o
local gsmd = luci.util.ubus("gsmd", "get_modems") or {}
local uci = require("luci.model.uci").cursor()
local ds = require "luci.dispatcher"

m = Map("periodic_reboot")

s = m:section(TypedSection, "reboot_instance", translate("Periodic Reboot"),
	translate("Periodic Reboot Instances"))
s.addremove = true
s.anonymous = true
s.template = "cbi/tblsection"
s.add_toggled = true
s.extedit = ds.build_url("admin/services/auto-reboot/periodic-reboot/%s")
s.description = translate("This section is used to set up Periodic Reboot instances - a function that reboots the router at a specified frequency regardless of other circumstances. It can be used as a prophylactic measure, for example, to reboot the router once at the end of every day.")

function s.create(self)
	stat = TypedSection.create(self, name)
	uci:set(self.config, stat, "action", "1")
	uci:set(self.config, stat, "hour", "12")
	uci:set(self.config, stat, "minute", "00")
	uci:set(self.config, stat, "days", "mon")

	luci.http.redirect(ds.build_url("admin/services/auto-reboot/periodic-reboot", stat))
	return stat
end

o = s:option(DummyValue, "action", translate("Action"),
	translate("Action that will be executed at specified time"))
o.cfgvalue = function (self, section)
	local value = self.map:get(section, self.option)
	local actions = {translate("Reboot"), translate("Modem reboot"), translate("None")}

	return value and actions[tonumber(value)] or translate("None")
end

o = s:option(DummyValue, "days", translate("Days"), translate("Days when action should be executed"))

-- Capitalize every first letter of days string
function o.value(self, section)
	local days = uci:get(self.config, section, "days")
	if days then
		days = days .. ","
		local days_array = days:gmatch("(.-),")
		local days_string = ""
		for day in days_array do
			-- Add comma if atleast one day is already in the string
			if #days_string > 0 then
				days_string = days_string .. ", "
			end
			--
			day = day:sub(1,1):upper()..day:sub(2)
			days_string = days_string .. day
		end

		return days_string
	end
	return "-"
end

o = s:option(DummyValue, "time", translate("Time"), translate("Day time when action should be executed"))
function o.value(self, section)
	local hour = uci:get(self.config, section, "hour")
	local minute = uci:get(self.config, section, "minute")
	if hour and minute then 
		return hour .. ":" .. minute
	end
	return "-"
end

o = s:option(Flag, "enable", translate("Enable"), translate("Enable periodic reboot instance"))
o.rmempty = false

return m