local dsp = require "luci.dispatcher"
local m, s, o

local cfgvalue = function (self, section)
	local value = self.map:get(section, self.option)
	return value and value:gsub("^%l", string.upper) or "-"
end

m = Map("ping_reboot")

s = m:section(TypedSection,"ping_reboot", translate("Ping Reboot Settings"),translate("This section displays Ping Reboot rules."
.." Ping Reboot is a health monitoring function that periodically sends ICMP or Wget requests to a specified IP address or host and waits for a response. If no response is received, the device will execute a specified action (reboot, by default).Click the 'Add' button to create more rules."))
s.addremove = true
s.template_addremove = "cbi/add_rule"
s.template = "cbi/tblsection"
s.anonymous = true
s.extedit = dsp.build_url("admin", "services", "auto-reboot", "ping-reboot", "%s")
s.delete_alert = true

o = s:option(DummyValue, "type", translate("Type"), translate("Ping/Wget"))
o.cfgvalue = cfgvalue

o = s:option(DummyValue, "action", translate("Action"),
	translate("Action after the defined number of unsuccessfull retries (no echo reply for sent ICMP (Internet Control Message Protocol) packet received)"))
o.cfgvalue = function (self, section)
	local value = self.map:get(section, self.option)
	local actions = {translate("Reboot"), translate("Modem reboot"), translate("None")}

	return value and actions[tonumber(value)] or translate("None")
end

o = s:option(DummyValue, "time", translate("Interval (min)"),
	translate("Time interval in minutes between two ping packets"))
o.cfgvalue = cfgvalue

o = s:option(DummyValue, "time_out", translate("Ping timeout (sec)"),
	translate("Time interval (in seconds) to wait for ICMP (Internet Control Message Protocol) echo reply packet. Range [1 - 9999]"))
o.cfgvalue = cfgvalue
o = s:option(DummyValue, "retry", translate("Try count"),
	translate("Number of failed to receive ICMP (Internet Control Message Protocol) echo reply packets. Range [1 - 9999]"))
o.cfgvalue = cfgvalue

o = s:option(DummyValue, "host", translate("Host"),
	translate("IP addresses or domain names which will be used to send ping packets to. E.g. 192.168.1.1 (or www.host.com if DNS server is configured correctly)"))

function o.cfgvalue(self, section)
	local value, option
	local hosts = {}

	for i=0, 2 do
		option = i > 0 and "host" .. i or "host"
		local host = self.map:get(section, option)

		if host then
			table.insert(hosts, host)
		end
	end

	return #hosts > 0 and table.concat(hosts, ", ") or "-"
end

o = s:option(Flag, "enable", translate(""))
o.rmempty = false
o.last = true

return m
