local dsp = require "luci.dispatcher"
local uci   = require("luci.model.uci").cursor()
--local md = require "luci.model.modem"
local modem_list = {{id='1', name='Cellular 1'}, {id='2', name='Cellular 2'}} --md.get_all_modems()

local m, s, o
local sid = arg[1]

m = Map("ping_reboot")
m.redirect = dsp.build_url("admin", "services", "auto-reboot", "ping-reboot")

if not sid then
	luci.http.redirect(m.redirect)
end

s = m:section(NamedSection, sid, "ping_reboot", translate("Ping/Wget Reboot Settings"))
s.addremove = false

o = s:option(Flag, "enable", translate("Enable"), translate("Turns the rule on or off."))
o.rmempty = false

o = s:option(ListValue, "type", translate("Type"), translate("Ping/Wget"))
o:value("ping", "Ping")
o:value("wget", "Wget")

o = s:option(ListValue, "action", translate("Action if no echo is received"),
		translate("Action that will be executed if there is no response after the specified amount of retries."))
o.template = "auto-reboot/lvalue"
o:value("1", translate("Device reboot"))
if #modem_list > 0 then
	o:value("2", translate("Modem reboot"))
end
o:value("3", "None")

if #modem_list > 1 then
	o = s:option(ListValue, "modem", translate("Modem"))
	o:depends("action", "2")

	for i,v in ipairs(modem_list) do
		if v.id and v.name then
			o:value(v.id, translate(v.name))
		end
	end
end

o = s:option(ListValue, "time", translate("Interval between pings"),
		translate("Time interval in minutes between two ping packets. E.g. if 5 min is selected, action will be performed at every 5th minute"))
o.template = "auto-reboot/time"
o:value("1", translate("1 mins"))
o:value("2", translate("2 mins"))
o:value("3", translate("3 mins"))
o:value("4", translate("4 mins"))
o:value("5", translate("5 mins"))
o:value("15", translate("15 mins"))
o:value("30", translate("30 mins"))
o:value("60", translate("1 hour"))
o:value("120", translate("2 hours"))

o = s:option(Value, "time_out", translate("Ping timeout (sec)"),
		translate("Time interval (in seconds) to wait for ICMP (Internet Control Message Protocol) echo reply packet. Range [1 - 9999]"))
o.default = "10"
o.datatype = "range(1,9999)"
o.placeholder = "10"

o = s:option(Value, "packet_size", translate("Packet size"), translate("ICMP packet size in bytes."))
o.default = "56"
o.datatype = "range(0,1000)"
o:depends("type", "ping")
o.placeholder = "56"

o = s:option(Value, "retry", translate("Try count"),
		translate("Number of failed to receive ICMP (Internet Control Message Protocol) echo reply packets. Range [1 - 9999]"))
o.default = "2"
o.datatype = "range(1,9999)"
o.placeholder = "2"

o = s:option(Value, "host", translate("Host"),
		translate("Hostname or IP address to which the ping/Wget requests will be sent. E.g. 1.1.1.1 (or www.host.com if DNS server is configured correctly)"))
o.datatype = "host"
o.rmempty = false
o.default = "8.8.8.8"

o = s:option(DummyValue, "message", "")
o.default = ""
o.rawhtml = true
local aa = 0
function o.cfgvalue(self, section)
	aa = aa + 1
	if aa > 1 then
		local reboot_enable = self.map:get(section, "enable")
		local time_value = self.map:get(section, "time")
		local retry_value = self.map:get(section, "retry")
		local action = self.map:get(section, "action")

		--if time_value and retry_value and reboot_enable == "1" and action and action == "1" then
		--	self.map:messages("info", "Reboot will be performed after %d min.",
		--			tonumber(time_value) * tonumber(retry_value))
		--end
	end
end

return m
