local dsp = require "luci.dispatcher"
local util  = require "luci.util"
--local md = require "luci.model.modem"
local modem_list = {{id='1', name='Cellular 1'}, {id='2', name='Cellular 2'}} --md.get_all_modems()
local modems = {} -- list to save modems labels

local uci = require("luci.model.uci").cursor()

m = Map("periodic_reboot")
m.redirect = dsp.build_url("admin", "services", "auto-reboot", "periodic-reboot")
local sid = arg[1]
s = m:section(NamedSection, sid, "reboot_instance", translate("Modify Reboot instance"))
s.anonymous = true
s.addremove = false

o = s:option(Flag, "enable", translate('Enable'), translate("Enable reboot instance"))

o = s:option(ListValue, "action", translate("Action"), translate("Action that will be executed at specified time"))
o:value("1", translate("Device reboot"))
if #modem_list > 0 then
	o:value("2", translate("Modem reboot"))
end

if #modem_list > 1 then
	o = s:option(ListValue, "modem", translate("Modem"))
	o:depends("action", "2")

	for i,v in ipairs(modem_list) do
		if v.id and v.name then
			o:value(v.id, translate(v.name))
		end
	end
end

o = s:option(DropDown, "days", translate("Week Days"), translate("Week days, when the reboot should happen. Atleast one selected day is mandatory."))
o.multiple = true
o.default = "mon"
o.display = 5
o:value("mon", translate("Monday"))
o:value("tue", translate("Tuesday"))
o:value("wed", translate("Wednesday"))
o:value("thu", translate("Thursday"))
o:value("fri", translate("Friday"))
o:value("sat", translate("Saturday"))
o:value("sun", translate("Sunday"))
o.delimiter = ","
o.rmempty = false

function o.cfgvalue(self, section)
    local value = uci:get(self.config, section, "days")
    if value then 
        return value:gsub(",", " ")
    end
    return "mon"
end

o = s:option(Value, "time", translate("Day time (hh:mm)"), translate("Day time when action should be executed."))
o.placeholder = "12:00"
o.default = "12:00"
o.rmempty = false
o.datatype = "time"

function o.cfgvalue(self, section)
	local hour = uci:get(self.config, section, "hour")
	local minute = uci:get(self.config, section, "minute")
	if hour and minute then 
		return hour .. ":" .. minute
	end
end

function o.write(self, section, value)
    local hour, minute = value:match("(%d+):(%d+)")
    uci:set(self.config, section, "hour", hour)
    uci:set(self.config, section, "minute", minute)
end

return m